==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/UsersFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link Users}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class UsersFieldAttributes extends AbstractBeanAttributesDefinition{

    /** defaultUser (Database column: DEFAULT_USER) */
    static public AttributeDefinition defaultUser =
        new AttributeDefinition("defaultUser")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USERS")
                .setDatabaseId("DEFAULT_USER")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(boolean.class);

    /** email (Database column: EMAIL) */
    static public AttributeDefinition email =
        new AttributeDefinition("email")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USERS")
                .setDatabaseId("EMAIL")
                .setMandatory(true)
                .setMaxSize(45)
                .setType(String.class);

    /** enabled (Database column: ENABLED) */
    static public AttributeDefinition enabled =
        new AttributeDefinition("enabled")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USERS")
                .setDatabaseId("ENABLED")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(boolean.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USERS")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(200)
                .setType(String.class);

    /** name (Database column: NAME) */
    static public AttributeDefinition name =
        new AttributeDefinition("name")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USERS")
                .setDatabaseId("NAME")
                .setMandatory(true)
                .setMaxSize(500)
                .setType(String.class);

    /** nick (Database column: NICK) */
    static public AttributeDefinition nick =
        new AttributeDefinition("nick")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USERS")
                .setDatabaseId("NICK")
                .setMandatory(true)
                .setMaxSize(45)
                .setType(String.class);

    /** password (Database column: PASSWORD) */
    static public AttributeDefinition password =
        new AttributeDefinition("password")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USERS")
                .setDatabaseId("PASSWORD")
                .setMandatory(true)
                .setMaxSize(200)
                .setType(String.class);

    /** groups (Database column: PROFILEID) */
    static public AttributeDefinition groups =
        new AttributeDefinition("groups")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USERS")
                .setDatabaseId("PROFILEID")
                .setMandatory(true)
                .setMaxSize(200)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.Groups.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.Groups.class);

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(defaultUser.getName(),defaultUser);
        map.put(email.getName(),email);
        map.put(enabled.getName(),enabled);
        map.put(id.getName(),id);
        map.put(name.getName(),name);
        map.put(nick.getName(),nick);
        map.put(password.getName(),password);
        map.put(groups.getName(),groups);

        return map;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/UsersFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link Users}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class UsersFieldAttributes extends AbstractBeanAttributesDefinition{

    /** defaultUser (Database column: DEFAULT_USER) */
    static public AttributeDefinition defaultUser =
        new AttributeDefinition("defaultUser")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USERS")
                .setDatabaseId("DEFAULT_USER")
                .setMandatory(true)
                .setMaxSize(1)
                .setTreatAsBoolean(true)
                .setBooleanFalseValue("0")
                .setBooleanTrueValue("1")
                .setLovFixedList(Arrays.asList(new String[]{"1","0"}))
                .setType(boolean.class);

    /** email (Database column: EMAIL) */
    static public AttributeDefinition email =
        new AttributeDefinition("email")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USERS")
                .setDatabaseId("EMAIL")
                .setMandatory(false)
                .setMaxSize(45)
                .setType(String.class);

    /** enabled (Database column: ENABLED) */
    static public AttributeDefinition enabled =
        new AttributeDefinition("enabled")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USERS")
                .setDatabaseId("ENABLED")
                .setMandatory(true)
                .setMaxSize(1)
                .setTreatAsBoolean(true)
                .setBooleanFalseValue("0")
                .setBooleanTrueValue("1")
                .setLovFixedList(Arrays.asList(new String[]{"1","0"}))
                .setType(boolean.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USERS")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(200)
                .setType(String.class);

    /** name (Database column: NAME) */
    static public AttributeDefinition name =
        new AttributeDefinition("name")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USERS")
                .setDatabaseId("NAME")
                .setMandatory(false)
                .setMaxSize(500)
                .setType(String.class);

    /** nick (Database column: NICK) */
    static public AttributeDefinition nick =
        new AttributeDefinition("nick")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USERS")
                .setDatabaseId("NICK")
                .setMandatory(false)
                .setMaxSize(45)
                .setType(String.class);

    /** password (Database column: PASSWORD) */
    static public AttributeDefinition password =
        new AttributeDefinition("password")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USERS")
                .setDatabaseId("PASSWORD")
                .setMandatory(true)
                .setMaxSize(200)
                .setType(String.class);

    /** groups (Database column: PROFILEID) */
    static public AttributeDefinition groups =
        new AttributeDefinition("groups")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USERS")
                .setDatabaseId("PROFILEID")
                .setMandatory(false)
                .setMaxSize(200)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.Groups.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.Groups.class);

    /**
     * Gets description field.
     *
     * @return the description field
     */
    public static String getDescriptionField()
    {
        return "name";
    }

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(defaultUser.getName(),defaultUser);
        map.put(email.getName(),email);
        map.put(enabled.getName(),enabled);
        map.put(id.getName(),id);
        map.put(name.getName(),name);
        map.put(nick.getName(),nick);
        map.put(password.getName(),password);
        map.put(groups.getName(),groups);

        return map;
    }
}
